#
# spec file for package aerc
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2023 Hannes Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           aerc
Version:        0.20.1
Release:        1.2
Summary:        An email client for terminals
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Email/Clients
URL:            https://aerc-mail.org/
Source0:        https://git.sr.ht/~rjarry/aerc/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
Patch0:         fix-script-interpreter.patch
BuildRequires:  gcc
BuildRequires:  golang-packaging
BuildRequires:  make
BuildRequires:  notmuch-devel >= 0.37
BuildRequires:  scdoc
BuildRequires:  zstd
Requires:       dante
Requires:       w3m

%description
aerc is an email client that runs in terminals.

%prep
%autosetup -p1 -a1

%build
# Need for cache writes
export HOME=${PWD}

%if "%{_arch}" == "ppc64"
    export GOFLAGS=""
%else
    export GOFLAGS="-buildmode=pie -tags=notmuch"
%endif
%make_build CC=cc DATE="$(date -d "@${SOURCE_DATE_EPOCH}" +%Y-%m-%d)"

%install
%make_install PREFIX=%{_prefix} LIBEXECDIR=%{_libexecdir}/%{name}

%check
%gotest ./...
LC_ALL=C.UTF-8 ./filters/test.sh

%files
%license LICENSE
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_bindir}/%{name}
%{_bindir}/carddav-query
%{_libexecdir}/%{name}
%{_mandir}/man1/aerc.1.gz
%{_mandir}/man1/aerc-search.1.gz
%{_mandir}/man1/carddav-query.1.gz
%{_mandir}/man5/aerc-accounts.5.gz
%{_mandir}/man5/aerc-binds.5.gz
%{_mandir}/man5/aerc-config.5.gz
%{_mandir}/man5/aerc-imap.5.gz
%{_mandir}/man5/aerc-jmap.5.gz
%{_mandir}/man5/aerc-maildir.5.gz
%{_mandir}/man5/aerc-sendmail.5.gz
%{_mandir}/man5/aerc-notmuch.5.gz
%{_mandir}/man5/aerc-smtp.5.gz
%{_mandir}/man7/aerc-patch.7.gz
%{_mandir}/man7/aerc-tutorial.7.gz
%{_mandir}/man7/aerc-templates.7.gz
%{_mandir}/man7/aerc-stylesets.7.gz

%changelog
* Mon Jan 27 2025 Hannes Braun <apple.hannes@gmail.com> - 0.20.1
- Update to upstream version 0.20.1
  * Fixed: :sign and :encrypt descriptions overflow the review screen.
  * Fixed: some messages are hidden when using client side threading.
* Sat Jan 25 2025 Hannes Braun <apple.hannes@gmail.com> - 0.20.0
- Update to upstream version 0.20.0
  * copy-to now supports multiple destination folders.
  * All commands that involve composing messages (:compose, :reply, :recall,
    :unsubscribe and :forward) now have a new -s flag to skip opening the text
    editor and go directly to the review screen. Previously, this flag was
    restricted to calendar invitations response commands (:accept,
    :accept-tentative and :decline).
  * copy-to-replied now properly works without having copy-to also set.
  * copy-to-replied creates empty messages when copy-to is also set.
  * The address-book completion popovers now again appear under the field being
    completed.
  * The new-message bell is now rung again for threaded directories as well.
  * The "default" styleset status line background has been reset to the default
    color (light or dark, depending on your terminal color scheme) in order to
    make error, warning or success messages more readable.
  * Key bindings in the compose review screen are now displayed in the order in
    which they are defined in the [compose::review] section of binds.conf.
  * It is now possible to explicitly hide key bindings from the compose review
    screen by using a special " # -" annotation.
* Tue Jan 14 2025 Hannes Braun <apple.hannes@gmail.com> - 0.19.0
- Update to upstream version 0.19.0
  * New :redraw command to force a repaint of the screen.
  * New head and tail templates functions for strings.
  * New {{.AccountFrom}} template variable.
  * Replying to all will include the Sender in Cc.
  * Add -b flag to the :view command to open messages in a background tab.
  * AERC_ACCOUNT and AERC_FOLDER are now available in the signature command
    environment.
  * Filters will receive the actual COLUMNS and LINES values.
  * The :forward command now sets the forwarded flag.
  * Forwarded messages can now be searched for and filtered in notmuch and
    maildir.
  * Forwarded messages can be styled differently in the message list.
  * Forwarded messages can be identified with the {{.IsForwarded}} template.
  * The :flag command now sets/unsets/toggle the forwarded tag.
  * The notmuch backend now honors the forwarded flag, setting the "passed" tag.
  * The maildir backend now honors the forwarded/passed flag.
  * Auto-switch projects based on the message subject for the :patch command.
  * New :echo command that prints its arguments with templates resolved.
  * New use-envelope-from option in accounts.conf.
  * Command completion now displays descriptions next to completion items.
  * New completion_description style object in style sets used for rendering
    completion item descriptions.
  * :import-mbox can now import data from an URL.
  * Dynamic message list style can now match on multiple email headers.
  * The JMAP backend now supports full thread fetching and caching
    (limited within a single mailbox).
  * :expand-folder and :collapse-folder can now act on a non selected folder.
  * Filters commands can now provide their own paging by prefixing them with a
    "!" character. Doing so will disable the configured [viewer].pager and
    connect them directly to the terminal.
  * Reply to addresses in From and Reply-To headers with ":reply -f".
  * Fixed builtin calendar filter showing empty attendee list.
  * Terminal-based pinentry programs (e.g. pinentry-curses) now work properly.
  * Notmuch searches which explicitly contain tags from exclude-tags now return
    messages.
  * Invitations now honor the -a flag for :send.
  * Remove unwanted less than symbol from In-Reply-To header when Message-ID
    uses folding.
  * Aliases are now taken into account correctly when replying to own messages
    such as from the Sent folder or via a mailing list.
  * Some SMTP servers do not strip Bcc headers. aerc now removes them before
    sending emails to avoid leaking private information. A new strip-bcc = false
    option can be used in accounts.conf to revert to previous behaviour
    (preserve Bcc headers in outgoing messages).
  * There should no longer be any duplicates in recipient lists when replying.
  * GPG signatures and encrypted parts now use CRLF line endings as required by
    RFC 5322.
  * Template function quote only prefixes with a space if at quote depth 1.
  * Templates passed to the :reply command using the `-T` flag can now make use
    of {{.OriginalText}}.
  * The location of the command history file has changed to
    ${XDG_STATE_HOME:-$HOME/.local/state}/aerc/history.
  * Tab completions for text fields are run asynchronously. In-flight requests
    are cancelled when new input arrives.
  * Path completion now uses the normal filtering mechanism, respecting case
    sensitivity and the fuzzy completion option.
  * The html filter is now enabled by default, making w3m a weak runtime
    dependency. If it is not installed, viewing HTML emails will fail with an
    explicit error.
  * The default text/html filter will now run w3m in interactive mode.
  * The builtin html and html-unsafe filters can now take additional arguments
    that will be passed to w3m. This can be used to enable inline images when
    viewing text/html parts (e.g.: text/html = ! html-unsafe -sixel).
  * The templates exec commands is now executed with the filters exec $PATH
    similar to filter commands.
  * The default quoted_reply template now converts text/html parts to plain text
    before quoting them.
* Mon Jul 29 2024 Hannes Braun <apple.hannes@gmail.com> - 0.18.2
- Update to upstream version 0.18.2
  * Fixed builtin calendar filter error with non-GNU Awk.
  * Fixed detection of unicode width measurements on tmux 3.4.
  * Fixed dropping of events during large pastes.
  * Fixed Home and End key decoding for the st terminal.
* Mon Jul 15 2024 Hannes Braun <apple.hannes@gmail.com> - 0.18.1
- Update to upstream version 0.18.1
  * Fixed startup error if "log-file" directory does not exist.
  * Aerc is now less pedantic about invalid headers for the maildir and notmuch
    backends.
  * Error when trying to configure smtp-domain with STARTTLS enabled.
  * smtp-domain is now properly taken into account for TLS connections.
* Wed Jul 10 2024 Joshua Smith <smolsheep@opensuse.org>
- Update license to GPL-3.0-or-later -- See mailing list
  https://lists.sr.ht/~sircmpwn/aerc/%%3CCKGCI4U5ATJ4.SFCCWY4TB0M7@marty%%3E
* Tue Jul  2 2024 Hannes Braun <apple.hannes@gmail.com> - 0.18.0
- Update to upstream version 0.18.0
  * Add [ui].msglist-scroll-offset option to set a scroll offset for the
    message list.
  * Add new :align command to align the selected message at the top, center, or
    bottom of the message list.
  * Inline image previews when no filter is defined for image/* and the terminal
    supports it.
  * Add :bounce command to reintroduce messages into the transport system.
  * Message counts are available in statusline templates.
  * Execute IPC commands verbatim by providing the command and its args as a
    single argument in the shell.
  * Virtually any key binding can now be configured in binds.conf, including
    Shift+Alt+Control modifier combinations.
  * Configure default message list :split or :vsplit on startup with
    message-list-split in aerc.conf.
  * Create notmuch named queries with the :query command.
  * Specify a ":q" alias for quit.
  * The :detach command now understands globs similar to :attach.
  * Match filters on filename via ".filename,~<regexp> =".
  * Tell aerc how to handle file-based operations on multi-file notmuch messages
    with the account config option multi-file-strategy and the -m flag to
    :archive, :copy, :delete, and :move.
  * Add [ui].dialog-{position,width,height} to set the position, width and
    height of popover dialogs.
  * New pgp-self-encrypt option in accounts.conf.
  * Add --no-ipc flag to run "aerc mailto:...", "aerc mbox:...", and
    "aerc :<command...>" within the current aerc instance and prevent listening
    for IPC calls from other aerc instances.
  * Add config options disable-ipc-mailto and disable-ipc-mbox to make
    mailto:... and mbox:... commands always run in a new aerc instance.
  * Set global options in accounts.conf by placing them at the top of the file.
  * Silently close the terminal tab after piping a message to a command with
    ":pipe -s <cmd>".
  * New tag-modified hook for notmuch and JMAP accounts.
  * New flag-changed hook.
  * Add Notmuch search term completions to :query.
  * Add Notmuch completions for :cf, :filter and :search.
  * Add imaps+insecure to the available protocols, for connections that should
    ignore issues with certificate verification.
  * Add [ui].select-last-message option to position cursor at the bottom of the
    view.
  * Propagate terminal bell from the built-in terminal.
  * Added AERC_FOLDER_ROLE to hooks that have AERC_FOLDER.
  * Added {{.AccountBackend}} to templates.
  * Added AERC_ACCOUNT_BACKEND to hooks with AERC_ACCOUNT.
  * Per folder key bindings can now be defined for the message viewer.
  * Allow using existing directory name with ":query -f".
  * Allow specifying the folder to delete with :rmdir.
  * The address book is now used for :cc, :bcc and :forward.
  * Allow fallback to threading by subject with [ui].threading-by-subject.
  * Calendar responses now ignore case.
  * Allow account- and folder-specific binds to coexist.
  * Fixed crash when running :send with a :preview tab focused.
  * Deadlock when running "aerc mailto:foo@bar.com" without another instance of
    aerc already running.
  * Prevent a freeze for large-scale deletions with IMAP.
  * Mime-Version is no longer inserted in signed text parts headers. MTAs
    normalizing header case will not corrupt signatures anymore.
  * Restore previous behaviour of the new message bell which was broken in the
    last two releases for at least some setups.
  * The default [ui] settings and the "default" styleset have changed
    extensively. A no-color theme can be restored with the "monochrome"
    styleset.
  * The default "colorize" theme has been changed to use the base terminal
    colors.
  * The [viewer] section of stylesets now preserve default values as documented
    in aerc-stylesets(7) unless explicitly overridden.
  * Add Message-ID to the variables of [hooks].mail-received.
  * The TrayInfo template variable now includes a visual mark mode indicator.
  * The disable-ipc option in aerc.conf completely disables IPC.
  * Improved readability of the builtin calendar filter.
  * :open commands now preserve the original filename.
  * Unparsable accounts are skipped, instead of aerc exiting with an error.
  * Built-in descriptions for the default keybinds shown on the review screen
    will be deprecated in a future release. Descriptions can be added to those
    keybinds with inline comments in binds.conf.
* Fri May 10 2024 Hannes Braun <apple.hannes@gmail.com>
- Set locale to UTF-8 when testing filters
* Thu Apr 18 2024 Joshua Smith <smolsheep@opensuse.org>
- Build without date to improve reproducibility
- Enable and run tests
* Fri Apr  5 2024 Atri Bhattacharya <badshah400@gmail.com>
- Use full URL for package source (for tarball verification
  purposes).
- Use _service file to collect vendored sources in separate
  vendor.tar.zstd file.
- Set HOME to working dir to allow cache generation.
- Empty %%check section as recommended by rpmlint.
* Thu Feb  1 2024 Hannes Braun <apple.hannes@gmail.com> - 0.17.0
- Update to upstream version 0.17.0
  * New flagged criteria for :sort.
  * New :send-keys command to control embedded terminals.
  * Account aliases now support fnmatch-style wild cards.
  * New :suspend command bound to <C-z> by default.
  * Disable parent context bindings by declaring them empty.
  * Toggle folding with ":fold -t".
  * mail-deleted hook that triggers when a message is removed/moved from a
    folder.
  * mail-added hook that triggers when a message is added to a folder.
  * Improved command completion.
  * Customize key to trigger completion with $complete in binds.conf.
  * Setting complete-min-chars=manual in aerc.conf now disables automatic
    completion, leaving only manually triggered completion.
  * .ThreadUnread is now available in templates.
  * Allow binding commands to Alt+<number> keys.
  * AERC_ACCOUNT and AERC_ADDRESS_BOOK_CMD are now defined in the editor's
    environment when composing a message.
  * Reply with a different account than the current one with ":reply -A
    <account>".
  * New [ui].tab-title-viewer setting to configure the message viewer tab title.
  * The {{.Subject}} template is evaluated to the new option
    [ui].empty-subject if the subject is empty.
  * Change to a folder of another account with ":cf -a <account> <folder>".
  * Patch management with :patch.
  * Add file path to messages in templates as {{.Filename}}.
  * New :menu command to invoke other ex-commands based on a shell command
    output.
  * CLI flags to override paths to config files.
  * Automatically attach signing key with pgp-attach-key in accounts.conf.
  * Copy messages across accounts with ":cp -a <account> <folder>".
  * Move messages across accounts with ":mv -a <account> <folder>".
  * Support the draft flag.
  * Thread arrow prefixes are now fully configurable.
  * colorize support for wild cards "?" and "*".
  * Selection of headers in composer after ":compose -e" followed by ":edit -E".
  * Don't lose child messages of non-queried parents in notmuch threads
  * Notmuch folders defined by the query "*" handle search, filter, and unread
    counts correctly.
  * :open commands are now executed with "sh -c".
  * ":pipe" commands are now executed with "sh -c".
  * Message viewer tab titles will now show "(no subject)" if there is no
    subject in the viewed email.
  * Signature placement is now controlled via the {{.Signature}} template
    variable and not hard coded.
* Thu Sep 28 2023 Hannes Braun <apple.hannes@gmail.com> - 0.16.0
- Update to upstream version 0.16.0
  * JMAP support.
  * The new account wizard now supports all source and outgoing backends.
  * Edit email headers directly in the text editor with "[compose].edit-headers"
    in aerc.conf or with the "-e" flag for all compose related commands (e.g.
    ":compose", ":forward", ":recall", etc.).
  * Use ":save -A" to save all the named parts, not just attachments.
  * The "<Backspace>" key can now be bound.
  * "colorize" can style diff chunk function names with "diff_chunk_func".
  * Warn before sending emails with an empty subject with
    "empty-subject-warning" in aerc.conf.
  * IMAP now uses the delimiter advertised by the server.
  * carddav-query utility to use for "address-book-cmd".
  * Folder name mapping with "folder-map" in accounts.conf.
  * Use ":open -d" to automatically delete temporary files.
  * Remove headers from the compose window with ":header -d <name>".
  * ":attach -r <name> <cmd>" to pipe the attachments from a command.
  * New "msglist_gutter" and `msglist_pill` styles for message list scrollbar.
  * New "%%f" placeholder to "file-picker-cmd" which expands to a location of a
    temporary file from which selected files will be read instead of the
    standard output.
  * Save drafts in custom folders with ":postpone -t <folder>".
  * View "thread-context" in notmuch backends with ":toggle-thread-context".
  * ":archive" now works on servers using a different delimiter.
  * ":save -a" now works with multiple attachments with the same filename.
  * ":open" uses the attachment extension for temporary files, if possible.
  * Fixed memory leak when using notmuch with threading.
  * Names formatted like "Last Name, First Name" are better supported in
    templates
  * Composing an email is now aborted if the text editor exits with an error
    (e.g. with "vim", abort an email with ":cq").
  * Aerc builtin filters path (usually "/usr/libexec/aerc/filters") is now
    prepended to the default system "PATH" to avoid conflicts with installed
    distro binaries which have the same name as aerc builtin filters (e.g.
    "/usr/bin/colorize").
  * ":export-mbox" only exports marked messages, if any. Otherwise it exports
    everything, as usual.
  * The local hostname is no longer exposed in outgoing "Message-Id" headers by
    default. Legacy behaviour can be restored by setting "send-with-hostname
    = true" in accounts.conf.
  * Aerc now has a default style for most UI elements. The "default" styleset is
    now empty. Existing stylesets will only override the default attributes if
    they are set explicitly. To reset the default style and preserve existing
    stylesets appearance, these two lines must be inserted at the beginning:
  * .default=true
  * .normal=true
- Update fix-script-interpreter.patch to patch the shebang of carddav-query
* Sun Aug  6 2023 Joshua Smith <jsmithfpv@gmail.com>
- Add dante and w3m to Recommends due to html filters.
* Thu May 11 2023 Jan Engelhardt <jengelh@inai.de>
- Trim rhetorics from descriptions.
* Thu May 11 2023 Hannes Braun <apple.hannes@gmail.com> - 0.15.2
- Update to upstream version 0.15.2
  * Extra messages disappearing when deleting on maildir.
  * "colorize" and "wrap" filters option parsing on ARM.
* Fri Apr 28 2023 Hannes Braun <apple.hannes@gmail.com> - 0.15.1
- Update to upstream version 0.15.1
  * Fix embedded terminal partial refreshes.
  * Fix maildir message updates after "mbsync".
* Thu Apr 27 2023 Hannes Braun <apple.hannes@gmail.com> - 0.15.0
- Update to upstream version 0.15.0
  * New column-based message list format with "index-columns".
  * Add a "msglist_answered" style for answered messages.
  * Compose "Format=Flowed" messages with "format-flowed=true" in aerc.conf.
  * Add a trimSignature function to the templating engine.
  * Change local domain name for SMTP with "smtp-domain=example.com" in
    aerc.conf
  * New column-based status line format with "status-columns".
  * Inline user-defined styles can be inserted in UI templates via the
    {{.Style "name" string}} function.
  * Add the ability to run arbitrary commands over the socket. This can be
    disabled using the disable-ipc setting.
  * Allow configuring URL handlers via "x-scheme-handler/<scheme> [openers]" in
    aerc.conf.
  * Allow basic shell globbing in [openers] MIME types.
  * Dynamic "msglist_*" styling based on email header values in stylesets.
  * Add "mail-received", "aerc-startup", and "aerc-shutdown" hooks.
  * Search/filter by flags with the "-H" flag.
  * The built-in colorize filter theme is now configured in styleset files into
    the [viewer] section.
  * The standard Usenet signature delimiter "-- " is now prepended to
    "signature-file" and "signature-cmd" if not already present.
  * All aerc(1) commands now interpret aerc-templates(7) markup.
  * running commands (like mailto: or mbox:) no longer prints a success message
  * The built-in colorize filter now emits OSC 8 to mark URLs and emails. Set
    "[general].enable-osc8 = true" in aerc.conf to enable it.
  * [ui].index-format setting has been replaced by index-columns.
  * [statusline].render-format has been replaced by status-columns.
  * Removed support for [ui:subject...] contextual sections in aerc.conf.
  * [triggers] setting has been replaced by [hooks].
  * smtp-starttls setting in accounts.conf has been removed. All smtp://
    transports now assume STARTTLS and will fail if the server does not support
    it. To disable STARTTLS, use smtp+insecure://.
- Remove "filters-install-location.patch: merged into upstream
- Remove "fix-english-typos.patch": merged into upstream
* Sun Mar 26 2023 Hannes Braun <apple.hannes@gmail.com> - 0.14.0
- Fix ppc64 build
* Wed Mar  8 2023 Hannes Braun <apple.hannes@gmail.com> - 0.14.0
- Add group tag
- Add support for systems without a libexec directory
* Tue Jan 31 2023 Hannes Braun <apple.hannes@gmail.com> - 0.14.0
- Initial package creation with version 0.14.0
  * View common email envelope headers with ":envelope".
  * Notmuch accounts now support maildir operations: ":copy", ":move", ":mkdir",
    ":rmdir", ":archive" and the "copy-to" option.
  * Display messages from bottom to top with [ui].reverse-msglist-order=true in
    aerc.conf.
  * Display threads from bottom to top with [ui].reverse-thread-order=true in
    aerc.conf.
  * Style search results in the message list with msglist_result.*.
  * Preview messages with their attachments before sending with ":preview".
  * Filter commands now have AERC_FORMAT, AERC_SUBJECT and AERC_FROM
    defined in their environment.
  * Override the subject prefix for replies pattern with subject-re-pattern in
    accounts.conf.
  * Search/filter by absolute and relative date ranges with the "-d" flag.
  * LIST-STATUS and ORDEREDSUBJECT threading extensions support for imap.
  * Built-in wrap filter that does not mess up nested quotes and lists.
  * Write multipart/alternative messages with ":multipart" and commands defined
    in the new [multipart-converters] section of aerc.conf.
  * Close the message viewer before opening the composer with ":reply -c".
  * Attachment indicator in message list flags (by default a, but can be
    changed via [ui].icon-attachment in aerc.conf).
  * Open file picker menu with ":attach -m". The menu must be generated by an
    external command configured via [compose].file-picker-cmd in aerc.conf.
  * Sample stylesets are now installed in $PREFIX/share/aerc/stylesets.
  * The built-in colorize filter now has different themes.
  * pgp-provider now defaults to auto. It will use the system gpg unless
    the internal keyring exists and contains at least one key.
  * Calling ":split" or ":vsplit" without specifying a size, now attempts to use
    the terminal size to determine a useful split-size.
  * ":pipe -m git am -3" on patch series when Message-Id headers have not been
    generated by "git send-email".
  * Overflowing text in header editors while composing can now be scrolled
    horizontally.
  * Removed broken ":set" command.
